@@ -3,15 +3,15 @@ pub mod abstract_structs;
 pub mod abstract_traits;
 pub mod argsort;
 pub mod binary_search;
-pub mod bitset;
+pub mod bitwise;
 pub mod cmp;
 pub mod combinatorics;
-pub mod fenwick_tree_static;
+pub mod fenwick_tree;
 pub mod longest_common_prefix;
 pub mod modular_static;
 pub mod power;
 pub mod segment_tree;
-pub mod segment_tree_static;
+pub mod segment_tree_dynamic;
 pub mod sequence;
 pub mod sort;
 pub mod sparse_table;
